webui

package
v0.0.0-...-09171d8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type WebUIServer

type WebUIServer struct {
	Addr string
	// contains filtered or unexported fields
}

func NewWebUIServer

func NewWebUIServer(addr string, paClient *pulseaudio.PAClient, configManager *configuration.ConfigManager) *WebUIServer

func (*WebUIServer) BroadcastMessage

func (s *WebUIServer) BroadcastMessage(message []byte)

BroadcastMessage sends a message to all connected clients

func (*WebUIServer) NotifyConfigUpdate

func (s *WebUIServer) NotifyConfigUpdate(update interface{})

NotifyConfigUpdate sends a config update to all connected clients

func (*WebUIServer) NotifyControlValueUpdate

func (s *WebUIServer) NotifyControlValueUpdate(controlType, controlId string, value int)

NotifyControlValueUpdate sends a fast control value update to all connected clients

func (*WebUIServer) Start

func (s *WebUIServer) Start() error

Jump to